github
======

Add the relevant files to make your package ready for hosting on GitHub_. This
option is the base for all web related options.

This option takes care of the local package side of github (e.g. .gitignore file)
but you still need to register your project on github. See :doc:`github_tutorial`
for example.

Modifications
-------------

.. raw:: html
    :file: modifications.html



.. _GitHub: https://github.com/
